@@ -244,6 +244,8 @@ static void dynamic_dep_eval	   (GnmDependent *dep);
 static void dynamic_dep_debug_name (GnmDependent const *dep, GString *target);
 static void name_dep_eval	   (GnmDependent *dep);
 static void name_dep_debug_name	   (GnmDependent const *dep, GString *target);
+static void managed_dep_eval	   (GnmDependent *dep);
+static void managed_dep_debug_name (GnmDependent const *dep, GString *target);
 
 static GnmCellPos const dummy = { 0, 0 };
 static GPtrArray *dep_classes = NULL;
@@ -257,6 +259,11 @@ static GnmDependentClass name_dep_class = {
 	NULL,
 	name_dep_debug_name,
 };
+static GnmDependentClass managed_dep_class = {
+	managed_dep_eval,
+	NULL,
+	managed_dep_debug_name,
+};
 typedef struct {
 	GnmDependent  base;
 	GnmDependent *container;
@@ -275,6 +282,7 @@ dependent_types_init (void)
 	g_ptr_array_add	(dep_classes, NULL); /* Cell */
 	g_ptr_array_add	(dep_classes, &dynamic_dep_class);
 	g_ptr_array_add	(dep_classes, &name_dep_class);
+	g_ptr_array_add	(dep_classes, &managed_dep_class);
 
 #if USE_POOLS
 	micro_few_pool =
@@ -1231,6 +1239,44 @@ workbook_unlink_3d_dep (GnmDependent *dep)
 	g_hash_table_remove (wb->sheet_order_dependents, dep);
 }
 
+/*****************************************************************************/
+/*
+ * "Managed" dependent handling.
+ *
+ * A managed dependent is simply an expression set up to be maintained by
+ * the dependency system so it follows row/column insert/delete nicely.
+ *
+ * The expression being managed is typically a cell range, but can be any
+ * expression.  Everything is interpreted relative to A1 in the sheet.
+ */
+
+void
+dependent_managed_init (GnmDependent *dep, Sheet *sheet)
+{
+	memset (dep, 0, sizeof (dep));
+	dep->flags = DEPENDENT_MANAGED;
+	dep->sheet = sheet;
+}
+
+void
+dependent_managed_set_expr (GnmDependent *dep, GnmExprTop const *texpr)
+{
+	dependent_set_expr (dep, texpr);
+	if (texpr && dep->sheet)
+		dependent_link (dep);
+}
+
+static void
+managed_dep_eval (G_GNUC_UNUSED GnmDependent *dep)
+{
+}
+
+static void
+managed_dep_debug_name (GnmDependent const *dep, GString *target)
+{
+	g_string_append_printf (target, "Managed%p", (void *)dep);
+}
+
 /*****************************************************************************/
 
 static void
@@ -1244,6 +1290,8 @@ name_dep_debug_name (GnmDependent const *dep, GString *target)
 	g_string_append_printf (target, "Name%p", (void *)dep);
 }
 
+/*****************************************************************************/
+
 static void
 dynamic_dep_eval (G_GNUC_UNUSED GnmDependent *dep)
 {
@@ -1493,6 +1541,8 @@ iterate :
 			}
 			value_release (cell->value);
 			cell->value = v;
+
+			gnm_cell_unrender (cell);
 #ifdef DEBUG_EVALUATION
 			puts ("/* LOOP */");
 #endif
