@@ -36,7 +36,7 @@
 #include <commands.h>
 #include <ranges.h>
 #include <widgets/gnumeric-expr-entry.h>
-#include <gtk/gtktable.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #define DIALOG_DATA_TABLE_KEY "dialog-data-table"
