@@ -129,7 +129,7 @@ name_guru_in_list (NameGuruState *state, char const *name,
 
 		g_return_val_if_fail (nexpr != NULL, NULL);
 		g_return_val_if_fail (nexpr->name != NULL, NULL);
-		g_return_val_if_fail (nexpr->name->str != NULL, NULL);
+		g_return_val_if_fail (expr_name_name (nexpr) != NULL, NULL);
 
 		if (ignore_placeholders && expr_name_is_placeholder (nexpr))
 			continue;
@@ -137,7 +137,7 @@ name_guru_in_list (NameGuruState *state, char const *name,
 			continue;
 
 		/* no need for UTF-8 or collation magic, just equality */
-		if (strcmp (name, nexpr->name->str) == 0)
+		if (strcmp (name, expr_name_name (nexpr)) == 0)
 			return nexpr;
 	}
 
@@ -153,7 +153,7 @@ name_guru_set_expr (NameGuruState *state, GnmNamedExpr *nexpr)
 				 gnm_conventions_default);
 		gnm_expr_entry_load_from_text  (state->expr_entry, txt);
 		g_free (txt);
-		gtk_entry_set_text (state->name, nexpr->name->str);
+		gtk_entry_set_text (state->name, expr_name_name (nexpr));
 	} else {
 		gnm_expr_entry_load_from_text (state->expr_entry, "");
 		gtk_entry_set_text (state->name, "");
@@ -194,25 +194,25 @@ name_guru_update_sensitivity (NameGuruState *state, gboolean update_entries)
 		 **/
 
 		sheet_scope = name_guru_scope_is_sheet (state);
-		
+
 		in_list = name_guru_in_list (state, name, TRUE, sheet_scope);
-		
+
 		if (in_list != NULL) {
 			delete = delete && !in_list->is_permanent;
 			clear_selection = FALSE;
 		} else
 			add = TRUE;
-		
+
 		update = !add && in_list->is_editable;
 	}
-	
+
 	if (switchscope) {
 		GnmNamedExpr const *nexpr = state->cur_name;
-		
-		if (nexpr != NULL ) 
-			switchscope = !nexpr->is_permanent && 
-				(NULL == name_guru_in_list (state, nexpr->name->str, 
-						TRUE, (nexpr->pos.sheet == NULL)));   
+
+		if (nexpr != NULL )
+			switchscope = !nexpr->is_permanent &&
+				(NULL == name_guru_in_list (state, expr_name_name (nexpr),
+						TRUE, (nexpr->pos.sheet == NULL)));
 	}
 
 	gtk_widget_set_sensitive (state->delete_button, delete);
@@ -265,13 +265,16 @@ name_guru_populate_list (NameGuruState *state)
 		if (nexpr->pos.sheet != NULL) {
 			char *name = g_strdup_printf ("%s!%s",
 						      nexpr->pos.sheet->name_unquoted,
-						      nexpr->name->str);
+						      expr_name_name (nexpr));
 			gtk_list_store_set (state->model,
 					    &iter, 0, name, 1, nexpr, -1);
 			g_free (name);
 		} else
 			gtk_list_store_set (state->model,
-					    &iter, 0, nexpr->name->str, 1, nexpr, -1);
+					    &iter,
+					    0, expr_name_name (nexpr),
+					    1, nexpr,
+					    -1);
 	}
 	name_guru_update_sensitivity (state, TRUE);
 }
@@ -311,7 +314,7 @@ cb_name_guru_select_name (G_GNUC_UNUSED GtkTreeSelection *ignored,
 
 	g_return_if_fail (nexpr != NULL);
 	g_return_if_fail (nexpr->name != NULL);
-	g_return_if_fail (nexpr->name->str != NULL);
+	g_return_if_fail (expr_name_name (nexpr) != NULL);
 
 	state->cur_name = nexpr;
 
@@ -355,7 +358,7 @@ name_guru_switchscope (NameGuruState *state)
 
 	g_return_if_fail (nexpr != NULL);
 	g_return_if_fail (!nexpr->is_permanent);
-	
+
 	expr_name_set_scope (state->cur_name,
 			     (nexpr->pos.sheet == NULL) ?
 			     state->sheet : NULL);
@@ -391,7 +394,7 @@ name_guru_add (NameGuruState *state)
 		return TRUE;
 	}
 
-	if (!expr_name_validate (name)) {
+	if (!expr_name_validate (name, state->sheet)) {
 		go_gtk_notice_dialog (GTK_WINDOW (state->dialog),
 				      GTK_MESSAGE_ERROR,
 				      _("Invalid name"));
@@ -412,7 +415,8 @@ name_guru_add (NameGuruState *state)
 			return TRUE;
 
 		go_gtk_notice_dialog (GTK_WINDOW (state->dialog),
-				 GTK_MESSAGE_ERROR, perr.err->message);
+				      GTK_MESSAGE_ERROR,
+				      "%s", perr.err->message);
 		gtk_widget_grab_focus (GTK_WIDGET (state->expr_entry));
 		parse_error_free (&perr);
 		return FALSE;
