@@ -101,6 +101,9 @@ render_val (GnmValue const *v, int i, int j,
 			return NULL;
 		gnm_cell_eval (cell);
 		v = cell->value;
+
+		if (fmt == NULL)
+			fmt = gnm_cell_get_format (cell);
 	} else if (v->type == VALUE_ARRAY)
 		v = value_area_get_x_y (v, i, j, ep);
 
@@ -1063,7 +1066,8 @@ gnm_go_data_matrix_get_value (GODataMatrix *dat, unsigned i, unsigned j)
 		gnm_go_data_matrix_load_size (dat);
 
 	eval_pos_init_dep (&ep, &mat->dep);
-	v = value_dup (value_area_get_x_y (mat->val, i, j, &ep));
+	/* i is row and j is column */
+	v = value_dup (value_area_get_x_y (mat->val, j, i, &ep));
 	if (NULL == v)
 		return go_nan;
 
