@@ -28,12 +28,12 @@
 #define ICG_POPUP_DELAY 3.0
 
 #define IO_CONTEXT_GTK_CLASS(klass) \
-    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IO_CONTEXT_GTK, IOContextGtk))
-#define IS_IO_CONTEXT_GTK_CLASS(klass) \
-    (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IO_CONTEXT_GTK))
+    (G_TYPE_CHECK_CLASS_CAST ((klass), GO_TYPE_IO_CONTEXT_GTK, IOContextGtk))
+#define GO_IS_IO_CONTEXT_GTK_CLASS(klass) \
+    (G_TYPE_CHECK_CLASS_TYPE ((klass), GO_TYPE_IO_CONTEXT_GTK))
 
-struct _IOContextGtk {
-	IOContext parent;
+struct _GOIOContextGtk {
+	GOIOContext parent;
 	GtkWindow *window;
 	GtkWindow *parent_window;
 	GtkProgressBar *file_bar;
@@ -42,7 +42,7 @@ struct _IOContextGtk {
 	guint files_total;
 	guint files_done;
 
-	gfloat progress;
+	double progress;
 	char *progress_msg;
 	gdouble latency;
 
@@ -52,8 +52,8 @@ struct _IOContextGtk {
 	gboolean show_warnings;
 };
 
-struct _IOContextGtkClass {
-	IOContextClass parent_class;
+struct _GOIOContextGtkClass {
+	GOIOContextClass parent_class;
 };
 
 enum {
@@ -146,8 +146,9 @@ icg_show_gui (IOContextGtk *icg)
 		gtk_progress_bar_set_orientation (
 			icg->file_bar, GTK_PROGRESS_LEFT_TO_RIGHT);
 		gtk_progress_bar_set_text (icg->file_bar, "Files");
-		gtk_progress_bar_set_fraction (icg->file_bar,
-			(float) icg->files_done / (float) icg->files_total);
+		gtk_progress_bar_set_fraction
+			(icg->file_bar,
+			 icg->files_done / (double)icg->files_total);
 		gtk_box_pack_start (box, GTK_WIDGET (icg->file_bar),
 			FALSE, FALSE, 0);
 	}
@@ -188,8 +189,8 @@ static gboolean
 icg_user_is_impatient (IOContextGtk *icg)
 {
 	gdouble t = g_timer_elapsed (icg->timer, NULL);
-	gfloat progress = icg->progress;
-	gfloat forecast_delay = ICG_POPUP_DELAY / 3.0;
+	double progress = icg->progress;
+	double forecast_delay = ICG_POPUP_DELAY / 3.0;
 	gboolean ret = FALSE;
 
 	if (icg->progress == 0. && icg->files_done == 0)
@@ -204,7 +205,7 @@ icg_user_is_impatient (IOContextGtk *icg)
 			/* We're likely to be back shortly.  */
 			ret = (t > ICG_POPUP_DELAY * 0.8);
 		} else {
-			gfloat forecast = icg->latency;
+			double forecast = icg->latency;
 			forecast += (t - icg->latency) / progress;
 			ret = (forecast > ICG_POPUP_DELAY);
 		}
@@ -222,7 +223,7 @@ icg_get_password (GOCmdContext *cc, char const *filename)
 }
 
 static void
-icg_progress_set (GOCmdContext *cc, gfloat val)
+icg_progress_set (GOCmdContext *cc, double val)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (cc);
 
@@ -258,11 +259,11 @@ icg_progress_message_set (GOCmdContext *cc, gchar const *msg)
 }
 
 static void
-icg_error_error_info (GOCmdContext *cc, ErrorInfo *error)
+icg_error_error_info (GOCmdContext *cc, GOErrorInfo *error)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (cc);
 	if (icg->show_warnings) {
-		GtkWidget *dialog = gnumeric_error_info_dialog_new (error);
+		GtkWidget *dialog = gnumeric_go_error_info_dialog_new (error);
 		gtk_widget_show_all (GTK_WIDGET (dialog));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -270,13 +271,13 @@ icg_error_error_info (GOCmdContext *cc, ErrorInfo *error)
 }
 
 static void
-icg_set_num_files (IOContext *icg, guint files_total)
+icg_set_num_files (GOIOContext *icg, guint files_total)
 {
 	IO_CONTEXT_GTK (icg)->files_total = files_total;
 }
 
 static void
-icg_processing_file (IOContext *ioc, char const *file)
+icg_processing_file (GOIOContext *ioc, char const *file)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (ioc);
 
@@ -288,8 +289,9 @@ icg_processing_file (IOContext *ioc, char const *file)
 		int maxlen = 40;
 
 		if (icg->files_total > 0)
-			gtk_progress_bar_set_fraction (icg->file_bar,
-				 (float) icg->files_done / (float) icg->files_total);
+			gtk_progress_bar_set_fraction
+				(icg->file_bar,
+				 icg->files_done / (double)icg->files_total);
 
 		gtk_progress_bar_set_fraction (icg->work_bar, 0.0);
 
@@ -339,7 +341,7 @@ icg_finalize (GObject *obj)
 		g_timer_destroy (icg->timer);
 	icg->timer = NULL;
 
-	G_OBJECT_CLASS (g_type_class_peek (TYPE_IO_CONTEXT))->finalize (obj);
+	G_OBJECT_CLASS (g_type_class_peek (GO_TYPE_IO_CONTEXT))->finalize (obj);
 }
 
 static void
@@ -372,7 +374,7 @@ icg_gnm_cmd_context_init (GOCmdContextClass *cc_class)
 static void
 icg_class_init (GObjectClass *gobj_klass)
 {
-	IOContextClass *ioc_klass = (IOContextClass *)gobj_klass;
+	GOIOContextClass *ioc_klass = (GOIOContextClass *)gobj_klass;
 
 	gobj_klass->finalize	   = icg_finalize;
 	gobj_klass->set_property   = icg_set_property;
@@ -413,7 +415,7 @@ icg_init (IOContextGtk *icg)
 
 GSF_CLASS_FULL (IOContextGtk, io_context_gtk,
 		NULL, NULL, icg_class_init, NULL,
-		icg_init, TYPE_IO_CONTEXT, 0,
+		icg_init, GO_TYPE_IO_CONTEXT, 0,
 		GSF_INTERFACE (icg_gnm_cmd_context_init, GO_TYPE_CMD_CONTEXT))
 
 void
