@@ -17,6 +17,7 @@
 #include "parse-util.h"
 #include "workbook.h"
 #include "workbook-priv.h"
+#include "workbook-control.h"
 #include "sheet.h"
 #include "dependent.h"
 #include "expr-name.h"
@@ -40,6 +41,7 @@ static gboolean ssconvert_list_exporters = FALSE;
 static gboolean ssconvert_list_importers = FALSE;
 static gboolean ssconvert_one_file_per_sheet = FALSE;
 static gboolean ssconvert_recalc = FALSE;
+static gboolean ssconvert_solve = FALSE;
 static char *ssconvert_range = NULL;
 static char *ssconvert_import_encoding = NULL;
 static char *ssconvert_import_id = NULL;
@@ -112,21 +114,21 @@ static const GOptionEntry ssconvert_options [] = {
 	{
 		"export-file-per-sheet", 'S',
 		0, G_OPTION_ARG_NONE, &ssconvert_one_file_per_sheet,
-		N_("Export a file for each sheet if the exporter only supports one sheet at a time."),
+		N_("Export a file for each sheet if the exporter only supports one sheet at a time"),
 		NULL
 	},
 
 	{
 		"recalc", 0,
 		0, G_OPTION_ARG_NONE, &ssconvert_recalc,
-		N_("Recalculate all cells before writing the result."),
+		N_("Recalculate all cells before writing the result"),
 		NULL
 	},
 
 
 	/* ---------------------------------------- */
 
-	/* For now this is for INTERNAL GNUMERIC USE ONLY.  */
+	/* For now these are for INTERNAL GNUMERIC USE ONLY.  */
 	{
 		"export-range", 0,
 		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, &ssconvert_range,
@@ -141,6 +143,13 @@ static const GOptionEntry ssconvert_options [] = {
 		NULL
 	},
 
+	{
+		"solve", 0,
+		0, G_OPTION_ARG_NONE, &ssconvert_solve,
+		N_("Run the solver"),
+		NULL
+	},
+
 	/* ---------------------------------------- */
 
 	{ NULL }
@@ -237,7 +246,7 @@ list_them (get_them_f get_them,
  */
 static GSList *
 read_files_to_merge (const char *inputs[], GOFileOpener *fo,
-		     IOContext *io_context, GOCmdContext *cc)
+		     GOIOContext *io_context, GOCmdContext *cc)
 {
 	GSList *wbs = NULL;
 
@@ -250,7 +259,7 @@ read_files_to_merge (const char *inputs[], GOFileOpener *fo,
 		g_free (uri);
 		inputs++;
 
-		if (gnumeric_io_error_occurred (io_context)) {
+		if (go_io_error_occurred (io_context)) {
 			go_slist_free_custom (wbs, g_object_unref);
 			return NULL;
 		}
@@ -351,6 +360,7 @@ merge_single (Workbook *wb, Workbook *wb2,
 		int loc = workbook_sheet_count (wb);
 		GOUndo *undo;
 		char *sheet_name;
+		gboolean err;
 
 		g_object_ref (sheet);
 		workbook_sheet_delete (sheet);
@@ -359,7 +369,7 @@ merge_single (Workbook *wb, Workbook *wb2,
 		/* Fix names that reference the old workbook */
 		gnm_sheet_foreach_name (sheet, (GHFunc)cb_fixup_name_wb, wb);
 
-		undo = gnm_sheet_resize (sheet, cmax, rmax, cc);
+		undo = gnm_sheet_resize (sheet, cmax, rmax, cc, &err);
 		if (undo)
 			g_object_unref (undo);
 
@@ -381,15 +391,15 @@ merge_single (Workbook *wb, Workbook *wb2,
 /* Merge a collection of workbooks into one. */
 static gboolean
 merge (Workbook *wb, char const *inputs[],
-       GOFileOpener *fo, IOContext *io_context, GOCmdContext *cc)
+       GOFileOpener *fo, GOIOContext *io_context, GOCmdContext *cc)
 {
 	GSList *wbs, *l;
 	int result = 0;
 	int cmax, rmax;
 
 	wbs = read_files_to_merge (inputs, fo, io_context, cc);
-	if (gnumeric_io_error_occurred (io_context)) {
-		gnumeric_io_error_display (io_context);
+	if (go_io_error_occurred (io_context)) {
+		go_io_error_display (io_context);
 		return TRUE;
 	}
 
@@ -410,6 +420,69 @@ merge (Workbook *wb, char const *inputs[],
 	return result;
 }
 
+static void
+run_solver (Sheet *sheet, WorkbookView *wbv)
+{
+	GnmSolverParameters *params = sheet->solver_parameters;
+	GError *err = NULL;
+	WorkbookControl *wbc;
+	GnmSolver *sol = NULL;
+
+	wbc = g_object_new (WORKBOOK_CONTROL_TYPE, NULL);
+	wb_control_set_view (wbc, wbv, NULL);
+
+	/* Pick a functional algorithm.  */
+	if (!gnm_solver_factory_functional (params->options.algorithm)) {
+		GSList *l;
+		for (l = gnm_solver_db_get (); l; l = l->next) {
+			GnmSolverFactory *factory = l->data;
+			if (params->options.model_type != factory->type)
+				continue;
+			if (gnm_solver_factory_functional (factory)) {
+				gnm_solver_param_set_algorithm (params,
+								factory);
+				break;
+			}
+		}
+	}
+
+	if (!gnm_solver_param_valid (params, &err))
+		goto done;
+
+	sol = params->options.algorithm
+		? gnm_solver_factory_create (params->options.algorithm, params)
+		: NULL;
+	if (!sol) {
+		g_set_error (&err, go_error_invalid (), 0,
+			     _("Failed to create solver"));
+		goto done;
+	}
+
+	if (!gnm_solver_start (sol, wbc, &err))
+		goto done;
+
+	while (!gnm_solver_finished (sol)) {
+		g_main_context_iteration (NULL, TRUE);
+	}
+
+	if (sol->status != GNM_SOLVER_STATUS_DONE) {
+		g_set_error (&err, go_error_invalid (), 0,
+			     _("Solver ran, but failed"));
+		goto done;
+	}
+
+	gnm_solver_store_result (sol);
+
+ done:
+	if (sol)
+		g_object_unref (sol);
+	if (err) {
+		g_printerr (_("Solver: %s\n"), err->message);
+		g_error_free (err);
+	}
+}
+
+
 static int
 convert (char const *inarg, char const *outarg, char const *mergeargs[],
 	 GOCmdContext *cc)
@@ -472,7 +545,7 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 	}
 
 	if (fs != NULL) {
-		IOContext *io_context = gnumeric_io_context_new (cc);
+		GOIOContext *io_context = go_io_context_new (cc);
 		WorkbookView *wbv;
 		if (mergeargs==NULL) {
 			wbv = wb_view_new_from_uri (infile, fo,
@@ -482,8 +555,8 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 			wbv = workbook_view_new (NULL);
 		}
 
-		if (wbv == NULL || gnumeric_io_error_occurred (io_context)) {
-			gnumeric_io_error_display (io_context);
+		if (wbv == NULL || go_io_error_occurred (io_context)) {
+			go_io_error_display (io_context);
 			res = 1;
 		} else {
 			Workbook *wb = wb_view_get_workbook (wbv);
@@ -512,6 +585,9 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 				}
 			}
 
+			if (ssconvert_solve)
+				run_solver (sheet, wbv);
+
 			if (ssconvert_recalc)
 				workbook_recalc_all (wb);
 			else
@@ -523,16 +599,30 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 					     wb,
 					     ssconvert_range);
 			else if (workbook_sheet_count (wb) > 1 &&
-				 go_file_saver_get_save_scope (fs) != FILE_SAVE_WORKBOOK) {
+				 go_file_saver_get_save_scope (fs) != GO_FILE_SAVE_WORKBOOK) {
 				if (ssconvert_one_file_per_sheet) {
-					g_warning ("TODO: one sheet per file is not implemented");
+					GSList *ptr;
+					GString *s;
+					char *tmpfile;
+					int idx = 0;
+					res = 0;
+					
+					for (ptr = workbook_sheets(wb); ptr && !res; ptr = ptr->next, idx++) {
+						wb_view_sheet_focus(wbv, (Sheet *)ptr->data);
+						s = g_string_new (outfile);
+						g_string_append_printf(s, ".%d", idx);
+						tmpfile = g_string_free (s, FALSE);
+						res = !wb_view_save_as (wbv, fs, tmpfile, cc);
+						g_free(tmpfile);
+					}
+					goto printing_done;
 				} else
 					g_printerr (_("Selected exporter (%s) does not support saving multiple sheets in one file.\n"
 						      "Only the current sheet will be saved.\n"),
 						    go_file_saver_get_id (fs));
 			}
 			res = !wb_view_save_as (wbv, fs, outfile, cc);
-
+		printing_done:
 			g_object_unref (wb);
 		}
 		g_object_unref (io_context);
@@ -548,7 +638,7 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 int
 main (int argc, char const **argv)
 {
-	ErrorInfo	*plugin_errs;
+	GOErrorInfo	*plugin_errs;
 	int		 res = 0;
 	GOCmdContext	*cc;
 	GOptionContext *ocontext;
@@ -584,7 +674,7 @@ main (int argc, char const **argv)
 		go_plugins_get_available_plugins (), &plugin_errs);
 	if (plugin_errs) {
 		/* FIXME: What do we want to do here? */
-		error_info_free (plugin_errs);
+		go_error_info_free (plugin_errs);
 	}
 
 	if (ssconvert_list_exporters)
