@@ -53,6 +53,7 @@
 
 #include <goffice/goffice.h>
 #include <gsf/gsf.h>
+#include <gsf/gsf-meta-names.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-stdio.h>
 #include <gsf/gsf-input.h>
@@ -65,10 +66,7 @@
 #include "mathfunc.h"
 
 #ifdef G_OS_WIN32
-#include <windef.h>
-#include <shellapi.h>
-#include <wingdi.h>
-#include <winuser.h>
+#include <windows.h>
 #endif
 
 enum {
@@ -311,7 +309,7 @@ wb_view_style_feedback (WorkbookView *wbv)
 
 	if (NULL != wbv->in_cell_combo)
 	{
-		float const a_offsets [4] = { 0., 0., 1., 1. };
+		const double a_offsets [4] = { 0., 0., 1., 1. };
 		SheetObjectAnchor  anchor;
 		GnmRange corner;
 		GnmRange const *r;
@@ -968,7 +966,11 @@ wbv_save_to_output (WorkbookView *wbv, GOFileSaver const *fs,
 {
 	GError const *err;
 	char const   *msg;
+	GODoc *godoc = wb_view_get_doc (wbv);
 
+	if (go_doc_is_dirty (godoc))
+	  /* FIXME: we should be using the true modification time */
+	  gnm_insert_meta_date (godoc, GSF_META_NAME_DATE_MODIFIED);
 	go_file_saver_save (fs, io_context, wbv, output);
 
 	/* The plugin convention is unclear */
